package
Version:
v0.0.0-...-02bc413
Opens a new window with list of versions in this module.
Published: Aug 26, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package xls implements the bounded OLE2 primitives needed to read BIFF8
workbooks. It is intentionally internal and is not a general OLE library.
Cell is a decoded BIFF cell value. Error is non-empty for Excel error cells.
Sheet is one materialized BIFF worksheet.
type Workbook struct {
Sheets []Sheet
}
Workbook is a bounded, materialized BIFF8 workbook.
Open parses the Workbook stream from an OLE2 compound file.
OpenWithPresence parses the workbook and records stored cell positions.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.